package com.ruoyi.branch.service;

import java.util.List;
import com.ruoyi.branch.domain.TBranchActivityBudget;

/**
 * 支部活动预算Service接口
 * 
 * @author ruoyi
 * @date 2023-07-20
 */
public interface ITBranchActivityBudgetService 
{
    /**
     * 查询支部活动预算
     * 
     * @param budgetId 支部活动预算主键
     * @return 支部活动预算
     */
    public TBranchActivityBudget selectTBranchActivityBudgetByBudgetId(Long budgetId);

    /**
     * 查询支部活动预算列表
     * 
     * @param tBranchActivityBudget 支部活动预算
     * @return 支部活动预算集合
     */
    public List<TBranchActivityBudget> selectTBranchActivityBudgetList(TBranchActivityBudget tBranchActivityBudget);

    /**
     * 新增支部活动预算
     * 
     * @param tBranchActivityBudget 支部活动预算
     * @return 结果
     */
    public int insertTBranchActivityBudget(TBranchActivityBudget tBranchActivityBudget);

    /**
     * 修改支部活动预算
     * 
     * @param tBranchActivityBudget 支部活动预算
     * @return 结果
     */
    public int updateTBranchActivityBudget(TBranchActivityBudget tBranchActivityBudget);

    /**
     * 批量删除支部活动预算
     * 
     * @param budgetIds 需要删除的支部活动预算主键集合
     * @return 结果
     */
    public int deleteTBranchActivityBudgetByBudgetIds(Long[] budgetIds);

    /**
     * 删除支部活动预算信息
     * 
     * @param budgetId 支部活动预算主键
     * @return 结果
     */
    public int deleteTBranchActivityBudgetByBudgetId(Long budgetId);
}
